// Generated by the protocol buffer compiler.  DO NOT EDIT!
// NO CHECKED-IN PROTOBUF GENCODE
// source: onnx/onnx-data.proto
// Protobuf C++ Version: 7.34.1

#ifndef onnx_2fonnx_2ddata_2eproto_2epb_2eh
#define onnx_2fonnx_2ddata_2eproto_2epb_2eh

#include <limits>
#include <string>
#include <type_traits>
#include <utility>

// clang-format off
#include "google/protobuf/runtime_version.h"
#if PROTOBUF_VERSION != 7034001
#error "Protobuf C++ gencode is built with an incompatible version of"
#error "Protobuf C++ headers/runtime. See"
#error "https://protobuf.dev/support/cross-version-runtime-guarantee/#cpp"
#endif
#include "google/protobuf/io/coded_stream.h"
#include "google/protobuf/arena.h"
#include "google/protobuf/arenastring.h"
#include "google/protobuf/generated_message_tctable_decl.h"
#include "google/protobuf/generated_message_util.h"
#include "google/protobuf/metadata_lite.h"
#include "google/protobuf/generated_message_reflection.h"
#include "google/protobuf/message.h"
#include "google/protobuf/message_lite.h"
#include "google/protobuf/repeated_field.h"  // IWYU pragma: export
#include "google/protobuf/extension_set.h"  // IWYU pragma: export
#include "google/protobuf/generated_enum_reflection.h"
#include "google/protobuf/unknown_field_set.h"
#include "onnx/onnx-ml.pb.h"
// @@protoc_insertion_point(includes)

// Must be included last.
#include "google/protobuf/port_def.inc"

#define PROTOBUF_INTERNAL_EXPORT_onnx_2fonnx_2ddata_2eproto

namespace google {
namespace protobuf {
namespace internal {
template <typename T>
::absl::string_view GetAnyMessageName();
}  // namespace internal
}  // namespace protobuf
}  // namespace google

// Internal implementation detail -- do not use these members.
struct TableStruct_onnx_2fonnx_2ddata_2eproto {
  static const ::uint32_t offsets[];
};
extern "C" {
extern const ::google::protobuf::internal::DescriptorTable descriptor_table_onnx_2fonnx_2ddata_2eproto;
}  // extern "C"
namespace onnx {
enum OptionalProto_DataType : int;
extern const uint32_t OptionalProto_DataType_internal_data_[];
enum SequenceProto_DataType : int;
extern const uint32_t SequenceProto_DataType_internal_data_[];
class MapProto;
struct MapProtoDefaultTypeInternal;
extern MapProtoDefaultTypeInternal _MapProto_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull MapProto_class_data_;
class OptionalProto;
struct OptionalProtoDefaultTypeInternal;
extern OptionalProtoDefaultTypeInternal _OptionalProto_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull OptionalProto_class_data_;
class SequenceProto;
struct SequenceProtoDefaultTypeInternal;
extern SequenceProtoDefaultTypeInternal _SequenceProto_default_instance_;
extern const ::google::protobuf::internal::ClassDataFull SequenceProto_class_data_;
}  // namespace onnx
namespace google {
namespace protobuf {
template <>
internal::EnumTraitsT<::onnx::OptionalProto_DataType_internal_data_>
    internal::EnumTraitsImpl::value<::onnx::OptionalProto_DataType>;
template <>
internal::EnumTraitsT<::onnx::SequenceProto_DataType_internal_data_>
    internal::EnumTraitsImpl::value<::onnx::SequenceProto_DataType>;
}  // namespace protobuf
}  // namespace google

namespace onnx {
enum SequenceProto_DataType : int {
  SequenceProto_DataType_UNDEFINED = 0,
  SequenceProto_DataType_TENSOR = 1,
  SequenceProto_DataType_SPARSE_TENSOR = 2,
  SequenceProto_DataType_SEQUENCE = 3,
  SequenceProto_DataType_MAP = 4,
  SequenceProto_DataType_OPTIONAL = 5,
};

extern const uint32_t SequenceProto_DataType_internal_data_[];
inline constexpr SequenceProto_DataType SequenceProto_DataType_DataType_MIN =
    static_cast<SequenceProto_DataType>(0);
inline constexpr SequenceProto_DataType SequenceProto_DataType_DataType_MAX =
    static_cast<SequenceProto_DataType>(5);
[[nodiscard]] inline bool SequenceProto_DataType_IsValid(int value) {
  return 0 <= value && value <= 5;
}
inline constexpr int SequenceProto_DataType_DataType_ARRAYSIZE = 5 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
SequenceProto_DataType_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(SequenceProto_DataType) {
  return SequenceProto_DataType_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& SequenceProto_DataType_Name(T value) {
  static_assert(::std::is_same<T, SequenceProto_DataType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to DataType_Name().");
  return SequenceProto_DataType_Name(static_cast<SequenceProto_DataType>(value));
}
template <>
[[nodiscard]] inline const ::std::string& SequenceProto_DataType_Name(SequenceProto_DataType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<SequenceProto_DataType_descriptor, 0, 5>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool SequenceProto_DataType_Parse(
    ::absl::string_view name, SequenceProto_DataType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<SequenceProto_DataType>(SequenceProto_DataType_descriptor(), name,
                                           value);
}
enum OptionalProto_DataType : int {
  OptionalProto_DataType_UNDEFINED = 0,
  OptionalProto_DataType_TENSOR = 1,
  OptionalProto_DataType_SPARSE_TENSOR = 2,
  OptionalProto_DataType_SEQUENCE = 3,
  OptionalProto_DataType_MAP = 4,
  OptionalProto_DataType_OPTIONAL = 5,
};

extern const uint32_t OptionalProto_DataType_internal_data_[];
inline constexpr OptionalProto_DataType OptionalProto_DataType_DataType_MIN =
    static_cast<OptionalProto_DataType>(0);
inline constexpr OptionalProto_DataType OptionalProto_DataType_DataType_MAX =
    static_cast<OptionalProto_DataType>(5);
[[nodiscard]] inline bool OptionalProto_DataType_IsValid(int value) {
  return 0 <= value && value <= 5;
}
inline constexpr int OptionalProto_DataType_DataType_ARRAYSIZE = 5 + 1;
[[nodiscard]] const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL
OptionalProto_DataType_descriptor();
[[nodiscard]] inline auto ProtobufInternalGetEnumDescriptor(OptionalProto_DataType) {
  return OptionalProto_DataType_descriptor();
}
template <typename T>
[[nodiscard]] const ::std::string& OptionalProto_DataType_Name(T value) {
  static_assert(::std::is_same<T, OptionalProto_DataType>::value ||
                    ::std::is_integral<T>::value,
                "Incorrect type passed to DataType_Name().");
  return OptionalProto_DataType_Name(static_cast<OptionalProto_DataType>(value));
}
template <>
[[nodiscard]] inline const ::std::string& OptionalProto_DataType_Name(OptionalProto_DataType value) {
  return ::google::protobuf::internal::NameOfDenseEnum<OptionalProto_DataType_descriptor, 0, 5>(
      static_cast<int>(value));
}
[[nodiscard]] inline bool OptionalProto_DataType_Parse(
    ::absl::string_view name, OptionalProto_DataType* PROTOBUF_NONNULL value) {
  return ::google::protobuf::internal::ParseNamedEnum<OptionalProto_DataType>(OptionalProto_DataType_descriptor(), name,
                                           value);
}

// ===================================================================


// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED MapProto final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:onnx.MapProto) */ {
 public:
  inline MapProto() : MapProto(nullptr) {}
  ~MapProto() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(MapProto* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(MapProto));
  }
#endif

  template <typename = void>
  explicit constexpr MapProto(::google::protobuf::internal::ConstantInitialized);

  inline MapProto(const MapProto& from) : MapProto(nullptr, from) {}
  inline MapProto(MapProto&& from) noexcept
      : MapProto(nullptr, ::std::move(from)) {}
  inline MapProto& operator=(const MapProto& from) {
    CopyFrom(from);
    return *this;
  }
  inline MapProto& operator=(MapProto&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const MapProto& default_instance() {
    return *reinterpret_cast<const MapProto*>(
        &_MapProto_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 1;
  friend void swap(MapProto& a, MapProto& b) { a.Swap(&b); }
  inline void Swap(MapProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(MapProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] MapProto* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<MapProto>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const MapProto& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const MapProto& from) { MapProto::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(MapProto* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "onnx.MapProto"; }

  explicit MapProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  MapProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const MapProto& from);
  MapProto(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, MapProto&& from) noexcept
      : MapProto(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------

  // accessors -------------------------------------------------------
  enum : int {
    kKeysFieldNumber = 3,
    kStringKeysFieldNumber = 4,
    kNameFieldNumber = 1,
    kValuesFieldNumber = 5,
    kKeyTypeFieldNumber = 2,
  };
  // repeated int64 keys = 3;
  [[nodiscard]] int keys_size()
      const;
  private:
  int _internal_keys_size() const;

  public:
  void clear_keys() ;
  [[nodiscard]] ::int64_t keys(int index) const;
  void set_keys(int index, ::int64_t value);
  void add_keys(::int64_t value);
  [[nodiscard]] const ::google::protobuf::RepeatedField<::int64_t>& keys() const;
  ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL mutable_keys();

  private:
  const ::google::protobuf::RepeatedField<::int64_t>& _internal_keys() const;
  ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL _internal_mutable_keys();

  public:
  // repeated bytes string_keys = 4;
  [[nodiscard]] int string_keys_size()
      const;
  private:
  int _internal_string_keys_size() const;

  public:
  void clear_string_keys() ;
  [[nodiscard]] const ::std::string& string_keys(int index) const;
  ::std::string* PROTOBUF_NONNULL mutable_string_keys(int index);
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_string_keys(int index, Arg_&& value, Args_... args);
  ::std::string* PROTOBUF_NONNULL add_string_keys();
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void add_string_keys(Arg_&& value, Args_... args);
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::std::string>&
  string_keys() const;
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
  mutable_string_keys();

  private:
  const ::google::protobuf::RepeatedPtrField<::std::string>& _internal_string_keys() const;
  ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL _internal_mutable_string_keys();

  public:
  // optional string name = 1;
  [[nodiscard]] bool has_name()
      const;
  void clear_name() ;
  [[nodiscard]] const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // optional .onnx.SequenceProto values = 5;
  [[nodiscard]] bool has_values()
      const;
  void clear_values() ;
  [[nodiscard]] const ::onnx::SequenceProto& values() const;
  [[nodiscard]] ::onnx::SequenceProto* PROTOBUF_NULLABLE release_values();
  ::onnx::SequenceProto* PROTOBUF_NONNULL mutable_values();
  void set_allocated_values(::onnx::SequenceProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_values(::onnx::SequenceProto* PROTOBUF_NULLABLE value);
  ::onnx::SequenceProto* PROTOBUF_NULLABLE unsafe_arena_release_values();

  private:
  const ::onnx::SequenceProto& _internal_values() const;
  ::onnx::SequenceProto* PROTOBUF_NONNULL _internal_mutable_values();

  public:
  // optional int32 key_type = 2;
  [[nodiscard]] bool has_key_type()
      const;
  void clear_key_type() ;
  [[nodiscard]] ::int32_t key_type() const;
  void set_key_type(::int32_t value);

  private:
  ::int32_t _internal_key_type() const;
  void _internal_set_key_type(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:onnx.MapProto)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<3, 5,
                                   1, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const MapProto& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedField<::int64_t> keys_;
    ::google::protobuf::RepeatedPtrField<::std::string> string_keys_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    ::onnx::SequenceProto* PROTOBUF_NULLABLE values_;
    ::int32_t key_type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_onnx_2fonnx_2ddata_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull MapProto_class_data_;
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED OptionalProto final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:onnx.OptionalProto) */ {
 public:
  inline OptionalProto() : OptionalProto(nullptr) {}
  ~OptionalProto() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(OptionalProto* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(OptionalProto));
  }
#endif

  template <typename = void>
  explicit constexpr OptionalProto(::google::protobuf::internal::ConstantInitialized);

  inline OptionalProto(const OptionalProto& from) : OptionalProto(nullptr, from) {}
  inline OptionalProto(OptionalProto&& from) noexcept
      : OptionalProto(nullptr, ::std::move(from)) {}
  inline OptionalProto& operator=(const OptionalProto& from) {
    CopyFrom(from);
    return *this;
  }
  inline OptionalProto& operator=(OptionalProto&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const OptionalProto& default_instance() {
    return *reinterpret_cast<const OptionalProto*>(
        &_OptionalProto_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 2;
  friend void swap(OptionalProto& a, OptionalProto& b) { a.Swap(&b); }
  inline void Swap(OptionalProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(OptionalProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] OptionalProto* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<OptionalProto>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const OptionalProto& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const OptionalProto& from) { OptionalProto::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(OptionalProto* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "onnx.OptionalProto"; }

  explicit OptionalProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  OptionalProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const OptionalProto& from);
  OptionalProto(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, OptionalProto&& from) noexcept
      : OptionalProto(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using DataType = OptionalProto_DataType;
  static constexpr DataType UNDEFINED = OptionalProto_DataType_UNDEFINED;
  static constexpr DataType TENSOR = OptionalProto_DataType_TENSOR;
  static constexpr DataType SPARSE_TENSOR = OptionalProto_DataType_SPARSE_TENSOR;
  static constexpr DataType SEQUENCE = OptionalProto_DataType_SEQUENCE;
  static constexpr DataType MAP = OptionalProto_DataType_MAP;
  static constexpr DataType OPTIONAL = OptionalProto_DataType_OPTIONAL;
  [[nodiscard]] static inline bool DataType_IsValid(int value) {
    return OptionalProto_DataType_IsValid(value);
  }
  static constexpr DataType DataType_MIN = OptionalProto_DataType_DataType_MIN;
  static constexpr DataType DataType_MAX = OptionalProto_DataType_DataType_MAX;
  static constexpr int DataType_ARRAYSIZE = OptionalProto_DataType_DataType_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL DataType_descriptor() {
    return OptionalProto_DataType_descriptor();
  }
  template <typename T>
  [[nodiscard]] static inline const ::std::string& DataType_Name(T value) {
    return OptionalProto_DataType_Name(value);
  }
  [[nodiscard]] static inline bool DataType_Parse(
      ::absl::string_view name, DataType* PROTOBUF_NONNULL value) {
    return OptionalProto_DataType_Parse(name, value);
  }

  // accessors -------------------------------------------------------
  enum : int {
    kNameFieldNumber = 1,
    kTensorValueFieldNumber = 3,
    kSparseTensorValueFieldNumber = 4,
    kSequenceValueFieldNumber = 5,
    kMapValueFieldNumber = 6,
    kOptionalValueFieldNumber = 7,
    kElemTypeFieldNumber = 2,
  };
  // optional string name = 1;
  [[nodiscard]] bool has_name()
      const;
  void clear_name() ;
  [[nodiscard]] const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // optional .onnx.TensorProto tensor_value = 3;
  [[nodiscard]] bool has_tensor_value()
      const;
  void clear_tensor_value() ;
  [[nodiscard]] const ::onnx::TensorProto& tensor_value() const;
  [[nodiscard]] ::onnx::TensorProto* PROTOBUF_NULLABLE release_tensor_value();
  ::onnx::TensorProto* PROTOBUF_NONNULL mutable_tensor_value();
  void set_allocated_tensor_value(::onnx::TensorProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_tensor_value(::onnx::TensorProto* PROTOBUF_NULLABLE value);
  ::onnx::TensorProto* PROTOBUF_NULLABLE unsafe_arena_release_tensor_value();

  private:
  const ::onnx::TensorProto& _internal_tensor_value() const;
  ::onnx::TensorProto* PROTOBUF_NONNULL _internal_mutable_tensor_value();

  public:
  // optional .onnx.SparseTensorProto sparse_tensor_value = 4;
  [[nodiscard]] bool has_sparse_tensor_value()
      const;
  void clear_sparse_tensor_value() ;
  [[nodiscard]] const ::onnx::SparseTensorProto& sparse_tensor_value() const;
  [[nodiscard]] ::onnx::SparseTensorProto* PROTOBUF_NULLABLE release_sparse_tensor_value();
  ::onnx::SparseTensorProto* PROTOBUF_NONNULL mutable_sparse_tensor_value();
  void set_allocated_sparse_tensor_value(::onnx::SparseTensorProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_sparse_tensor_value(::onnx::SparseTensorProto* PROTOBUF_NULLABLE value);
  ::onnx::SparseTensorProto* PROTOBUF_NULLABLE unsafe_arena_release_sparse_tensor_value();

  private:
  const ::onnx::SparseTensorProto& _internal_sparse_tensor_value() const;
  ::onnx::SparseTensorProto* PROTOBUF_NONNULL _internal_mutable_sparse_tensor_value();

  public:
  // optional .onnx.SequenceProto sequence_value = 5;
  [[nodiscard]] bool has_sequence_value()
      const;
  void clear_sequence_value() ;
  [[nodiscard]] const ::onnx::SequenceProto& sequence_value() const;
  [[nodiscard]] ::onnx::SequenceProto* PROTOBUF_NULLABLE release_sequence_value();
  ::onnx::SequenceProto* PROTOBUF_NONNULL mutable_sequence_value();
  void set_allocated_sequence_value(::onnx::SequenceProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_sequence_value(::onnx::SequenceProto* PROTOBUF_NULLABLE value);
  ::onnx::SequenceProto* PROTOBUF_NULLABLE unsafe_arena_release_sequence_value();

  private:
  const ::onnx::SequenceProto& _internal_sequence_value() const;
  ::onnx::SequenceProto* PROTOBUF_NONNULL _internal_mutable_sequence_value();

  public:
  // optional .onnx.MapProto map_value = 6;
  [[nodiscard]] bool has_map_value()
      const;
  void clear_map_value() ;
  [[nodiscard]] const ::onnx::MapProto& map_value() const;
  [[nodiscard]] ::onnx::MapProto* PROTOBUF_NULLABLE release_map_value();
  ::onnx::MapProto* PROTOBUF_NONNULL mutable_map_value();
  void set_allocated_map_value(::onnx::MapProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_map_value(::onnx::MapProto* PROTOBUF_NULLABLE value);
  ::onnx::MapProto* PROTOBUF_NULLABLE unsafe_arena_release_map_value();

  private:
  const ::onnx::MapProto& _internal_map_value() const;
  ::onnx::MapProto* PROTOBUF_NONNULL _internal_mutable_map_value();

  public:
  // optional .onnx.OptionalProto optional_value = 7;
  [[nodiscard]] bool has_optional_value()
      const;
  void clear_optional_value() ;
  [[nodiscard]] const ::onnx::OptionalProto& optional_value() const;
  [[nodiscard]] ::onnx::OptionalProto* PROTOBUF_NULLABLE release_optional_value();
  ::onnx::OptionalProto* PROTOBUF_NONNULL mutable_optional_value();
  void set_allocated_optional_value(::onnx::OptionalProto* PROTOBUF_NULLABLE value);
  void unsafe_arena_set_allocated_optional_value(::onnx::OptionalProto* PROTOBUF_NULLABLE value);
  ::onnx::OptionalProto* PROTOBUF_NULLABLE unsafe_arena_release_optional_value();

  private:
  const ::onnx::OptionalProto& _internal_optional_value() const;
  ::onnx::OptionalProto* PROTOBUF_NONNULL _internal_mutable_optional_value();

  public:
  // optional int32 elem_type = 2;
  [[nodiscard]] bool has_elem_type()
      const;
  void clear_elem_type() ;
  [[nodiscard]] ::int32_t elem_type() const;
  void set_elem_type(::int32_t value);

  private:
  ::int32_t _internal_elem_type() const;
  void _internal_set_elem_type(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:onnx.OptionalProto)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<3, 7,
                                   5, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const OptionalProto& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    ::onnx::TensorProto* PROTOBUF_NULLABLE tensor_value_;
    ::onnx::SparseTensorProto* PROTOBUF_NULLABLE sparse_tensor_value_;
    ::onnx::SequenceProto* PROTOBUF_NULLABLE sequence_value_;
    ::onnx::MapProto* PROTOBUF_NULLABLE map_value_;
    ::onnx::OptionalProto* PROTOBUF_NULLABLE optional_value_;
    ::int32_t elem_type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_onnx_2fonnx_2ddata_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull OptionalProto_class_data_;
// -------------------------------------------------------------------

class  PROTOBUF_FUTURE_ADD_EARLY_WARN_UNUSED SequenceProto final : public ::google::protobuf::Message
/* @@protoc_insertion_point(class_definition:onnx.SequenceProto) */ {
 public:
  inline SequenceProto() : SequenceProto(nullptr) {}
  ~SequenceProto() PROTOBUF_FINAL;

#if defined(PROTOBUF_CUSTOM_VTABLE)
  void operator delete(SequenceProto* PROTOBUF_NONNULL msg, ::std::destroying_delete_t) {
    SharedDtor(*msg);
    ::google::protobuf::internal::SizedDelete(msg, sizeof(SequenceProto));
  }
#endif

  template <typename = void>
  explicit constexpr SequenceProto(::google::protobuf::internal::ConstantInitialized);

  inline SequenceProto(const SequenceProto& from) : SequenceProto(nullptr, from) {}
  inline SequenceProto(SequenceProto&& from) noexcept
      : SequenceProto(nullptr, ::std::move(from)) {}
  inline SequenceProto& operator=(const SequenceProto& from) {
    CopyFrom(from);
    return *this;
  }
  inline SequenceProto& operator=(SequenceProto&& from) noexcept {
    if (this == &from) return *this;
    if (::google::protobuf::internal::CanMoveWithInternalSwap(GetArena(), from.GetArena())) {
      InternalSwap(&from);
    } else {
      CopyFrom(from);
    }
    return *this;
  }

  [[nodiscard]] inline const ::google::protobuf::UnknownFieldSet& unknown_fields() const
      ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.unknown_fields<::google::protobuf::UnknownFieldSet>(::google::protobuf::UnknownFieldSet::default_instance);
  }
  [[nodiscard]] inline ::google::protobuf::UnknownFieldSet* PROTOBUF_NONNULL
  mutable_unknown_fields() ABSL_ATTRIBUTE_LIFETIME_BOUND {
    return _internal_metadata_.mutable_unknown_fields<::google::protobuf::UnknownFieldSet>();
  }

  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL descriptor() {
    return GetDescriptor();
  }
  [[nodiscard]] static const ::google::protobuf::Descriptor* PROTOBUF_NONNULL
  GetDescriptor() {
    return default_instance().GetMetadata().descriptor;
  }
  [[nodiscard]] static const ::google::protobuf::Reflection* PROTOBUF_NONNULL GetReflection() {
    return default_instance().GetMetadata().reflection;
  }
  [[nodiscard]] static const SequenceProto& default_instance() {
    return *reinterpret_cast<const SequenceProto*>(
        &_SequenceProto_default_instance_);
  }
  static constexpr int kIndexInFileMessages = 0;
  friend void swap(SequenceProto& a, SequenceProto& b) { a.Swap(&b); }
  inline void Swap(SequenceProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    if (::google::protobuf::internal::CanUseInternalSwap(GetArena(), other->GetArena())) {
      InternalSwap(other);
    } else {
      ::google::protobuf::internal::GenericSwap(this, other);
    }
  }
  void UnsafeArenaSwap(SequenceProto* PROTOBUF_NONNULL other) {
    if (other == this) return;
    ABSL_DCHECK(GetArena() == other->GetArena());
    InternalSwap(other);
  }

  // implements Message ----------------------------------------------

  [[nodiscard]] SequenceProto* PROTOBUF_NONNULL
  New(::google::protobuf::Arena* PROTOBUF_NULLABLE arena = nullptr) const {
    return ::google::protobuf::Message::DefaultConstruct<SequenceProto>(arena);
  }
  using ::google::protobuf::Message::CopyFrom;
  void CopyFrom(const SequenceProto& from);
  using ::google::protobuf::Message::MergeFrom;
  void MergeFrom(const SequenceProto& from) { SequenceProto::MergeImpl(*this, from); }

  private:
  static void MergeImpl(::google::protobuf::MessageLite& to_msg,
                        const ::google::protobuf::MessageLite& from_msg);

  public:
  [[nodiscard]] bool IsInitialized() const {
    return true;
  }
  ABSL_ATTRIBUTE_REINITIALIZES void Clear() PROTOBUF_FINAL;
  #if defined(PROTOBUF_CUSTOM_VTABLE)
  private:
  [[nodiscard]] static ::size_t ByteSizeLong(const ::google::protobuf::MessageLite& msg);
  [[nodiscard]] static ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      const ::google::protobuf::MessageLite& msg, ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream);

  public:
  [[nodiscard]] ::size_t ByteSizeLong() const { return ByteSizeLong(*this); }
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const {
    return _InternalSerialize(*this, target, stream);
  }
  #else   // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] ::size_t ByteSizeLong() const final;
  [[nodiscard]] ::uint8_t* PROTOBUF_NONNULL _InternalSerialize(
      ::uint8_t* PROTOBUF_NONNULL target,
      ::google::protobuf::io::EpsCopyOutputStream* PROTOBUF_NONNULL stream) const final;
  #endif  // PROTOBUF_CUSTOM_VTABLE
  [[nodiscard]] int GetCachedSize() const {
    return _impl_._cached_size_.Get();
  }

  private:
  void SharedCtor(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static void SharedDtor(MessageLite& self);
  void InternalSwap(SequenceProto* PROTOBUF_NONNULL other);
 private:
  template <typename T>
  friend ::absl::string_view(::google::protobuf::internal::GetAnyMessageName)();
  static ::absl::string_view FullMessageName() { return "onnx.SequenceProto"; }

  explicit SequenceProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  SequenceProto(::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const SequenceProto& from);
  SequenceProto(
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, SequenceProto&& from) noexcept
      : SequenceProto(arena) {
    *this = ::std::move(from);
  }
  const ::google::protobuf::internal::ClassData* PROTOBUF_NONNULL GetClassData() const PROTOBUF_FINAL;
  static void* PROTOBUF_NONNULL PlacementNew_(
      const void* PROTOBUF_NONNULL, void* PROTOBUF_NONNULL mem,
      ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
  static constexpr auto InternalNewImpl_();

 public:
  static constexpr auto InternalGenerateClassData_();

  [[nodiscard]] ::google::protobuf::Metadata GetMetadata() const;
  // nested types ----------------------------------------------------
  using DataType = SequenceProto_DataType;
  static constexpr DataType UNDEFINED = SequenceProto_DataType_UNDEFINED;
  static constexpr DataType TENSOR = SequenceProto_DataType_TENSOR;
  static constexpr DataType SPARSE_TENSOR = SequenceProto_DataType_SPARSE_TENSOR;
  static constexpr DataType SEQUENCE = SequenceProto_DataType_SEQUENCE;
  static constexpr DataType MAP = SequenceProto_DataType_MAP;
  static constexpr DataType OPTIONAL = SequenceProto_DataType_OPTIONAL;
  [[nodiscard]] static inline bool DataType_IsValid(int value) {
    return SequenceProto_DataType_IsValid(value);
  }
  static constexpr DataType DataType_MIN = SequenceProto_DataType_DataType_MIN;
  static constexpr DataType DataType_MAX = SequenceProto_DataType_DataType_MAX;
  static constexpr int DataType_ARRAYSIZE = SequenceProto_DataType_DataType_ARRAYSIZE;
  static inline const ::google::protobuf::EnumDescriptor* PROTOBUF_NONNULL DataType_descriptor() {
    return SequenceProto_DataType_descriptor();
  }
  template <typename T>
  [[nodiscard]] static inline const ::std::string& DataType_Name(T value) {
    return SequenceProto_DataType_Name(value);
  }
  [[nodiscard]] static inline bool DataType_Parse(
      ::absl::string_view name, DataType* PROTOBUF_NONNULL value) {
    return SequenceProto_DataType_Parse(name, value);
  }

  // accessors -------------------------------------------------------
  enum : int {
    kTensorValuesFieldNumber = 3,
    kSparseTensorValuesFieldNumber = 4,
    kSequenceValuesFieldNumber = 5,
    kMapValuesFieldNumber = 6,
    kOptionalValuesFieldNumber = 7,
    kNameFieldNumber = 1,
    kElemTypeFieldNumber = 2,
  };
  // repeated .onnx.TensorProto tensor_values = 3;
  [[nodiscard]] int tensor_values_size()
      const;
  private:
  int _internal_tensor_values_size() const;

  public:
  void clear_tensor_values() ;
  [[nodiscard]] ::onnx::TensorProto* PROTOBUF_NONNULL mutable_tensor_values(int index);
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>* PROTOBUF_NONNULL
  mutable_tensor_values();

  private:
  const ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>& _internal_tensor_values() const;
  ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>* PROTOBUF_NONNULL _internal_mutable_tensor_values();
  public:
  [[nodiscard]] const ::onnx::TensorProto& tensor_values(int index) const;
  ::onnx::TensorProto* PROTOBUF_NONNULL add_tensor_values();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>& tensor_values()
      const;
  // repeated .onnx.SparseTensorProto sparse_tensor_values = 4;
  [[nodiscard]] int sparse_tensor_values_size()
      const;
  private:
  int _internal_sparse_tensor_values_size() const;

  public:
  void clear_sparse_tensor_values() ;
  [[nodiscard]] ::onnx::SparseTensorProto* PROTOBUF_NONNULL mutable_sparse_tensor_values(int index);
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>* PROTOBUF_NONNULL
  mutable_sparse_tensor_values();

  private:
  const ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>& _internal_sparse_tensor_values() const;
  ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>* PROTOBUF_NONNULL _internal_mutable_sparse_tensor_values();
  public:
  [[nodiscard]] const ::onnx::SparseTensorProto& sparse_tensor_values(int index) const;
  ::onnx::SparseTensorProto* PROTOBUF_NONNULL add_sparse_tensor_values();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>& sparse_tensor_values()
      const;
  // repeated .onnx.SequenceProto sequence_values = 5;
  [[nodiscard]] int sequence_values_size()
      const;
  private:
  int _internal_sequence_values_size() const;

  public:
  void clear_sequence_values() ;
  [[nodiscard]] ::onnx::SequenceProto* PROTOBUF_NONNULL mutable_sequence_values(int index);
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>* PROTOBUF_NONNULL
  mutable_sequence_values();

  private:
  const ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>& _internal_sequence_values() const;
  ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>* PROTOBUF_NONNULL _internal_mutable_sequence_values();
  public:
  [[nodiscard]] const ::onnx::SequenceProto& sequence_values(int index) const;
  ::onnx::SequenceProto* PROTOBUF_NONNULL add_sequence_values();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>& sequence_values()
      const;
  // repeated .onnx.MapProto map_values = 6;
  [[nodiscard]] int map_values_size()
      const;
  private:
  int _internal_map_values_size() const;

  public:
  void clear_map_values() ;
  [[nodiscard]] ::onnx::MapProto* PROTOBUF_NONNULL mutable_map_values(int index);
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::onnx::MapProto>* PROTOBUF_NONNULL
  mutable_map_values();

  private:
  const ::google::protobuf::RepeatedPtrField<::onnx::MapProto>& _internal_map_values() const;
  ::google::protobuf::RepeatedPtrField<::onnx::MapProto>* PROTOBUF_NONNULL _internal_mutable_map_values();
  public:
  [[nodiscard]] const ::onnx::MapProto& map_values(int index) const;
  ::onnx::MapProto* PROTOBUF_NONNULL add_map_values();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::onnx::MapProto>& map_values()
      const;
  // repeated .onnx.OptionalProto optional_values = 7;
  [[nodiscard]] int optional_values_size()
      const;
  private:
  int _internal_optional_values_size() const;

  public:
  void clear_optional_values() ;
  [[nodiscard]] ::onnx::OptionalProto* PROTOBUF_NONNULL mutable_optional_values(int index);
  [[nodiscard]] ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>* PROTOBUF_NONNULL
  mutable_optional_values();

  private:
  const ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>& _internal_optional_values() const;
  ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>* PROTOBUF_NONNULL _internal_mutable_optional_values();
  public:
  [[nodiscard]] const ::onnx::OptionalProto& optional_values(int index) const;
  ::onnx::OptionalProto* PROTOBUF_NONNULL add_optional_values();
  [[nodiscard]] const ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>& optional_values()
      const;
  // optional string name = 1;
  [[nodiscard]] bool has_name()
      const;
  void clear_name() ;
  [[nodiscard]] const ::std::string& name() const;
  template <typename Arg_ = const ::std::string&, typename... Args_>
  void set_name(Arg_&& arg, Args_... args);
  ::std::string* PROTOBUF_NONNULL mutable_name();
  [[nodiscard]] ::std::string* PROTOBUF_NULLABLE release_name();
  void set_allocated_name(::std::string* PROTOBUF_NULLABLE value);

  private:
  const ::std::string& _internal_name() const;
  PROTOBUF_ALWAYS_INLINE void _internal_set_name(const ::std::string& value);
  ::std::string* PROTOBUF_NONNULL _internal_mutable_name();

  public:
  // optional int32 elem_type = 2;
  [[nodiscard]] bool has_elem_type()
      const;
  void clear_elem_type() ;
  [[nodiscard]] ::int32_t elem_type() const;
  void set_elem_type(::int32_t value);

  private:
  ::int32_t _internal_elem_type() const;
  void _internal_set_elem_type(::int32_t value);

  public:
  // @@protoc_insertion_point(class_scope:onnx.SequenceProto)
 private:
  class _Internal;
  friend class ::google::protobuf::internal::TcParser;
  static const ::google::protobuf::internal::TcParseTable<3, 7,
                                   5, 0,
                                   2>
      _table_;

  friend class ::google::protobuf::MessageLite;
  friend class ::google::protobuf::Arena;
  friend ::google::protobuf::internal::PrivateAccess;
  template <typename T>
  friend class ::google::protobuf::Arena::InternalHelper;
  using InternalArenaConstructable_ = void;
  using DestructorSkippable_ = void;
  struct Impl_ {
    inline explicit constexpr Impl_(::google::protobuf::internal::InternalVisibility visibility,
                                    ::google::protobuf::internal::ConstantInitialized) noexcept;
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena);
    inline explicit Impl_(
        ::google::protobuf::internal::InternalVisibility visibility,
        ::google::protobuf::Arena* PROTOBUF_NULLABLE arena, const Impl_& from,
        const SequenceProto& from_msg);
    ::google::protobuf::internal::HasBits<1> _has_bits_;
    ::google::protobuf::internal::CachedSize _cached_size_;
    ::google::protobuf::RepeatedPtrField< ::onnx::TensorProto > tensor_values_;
    ::google::protobuf::RepeatedPtrField< ::onnx::SparseTensorProto > sparse_tensor_values_;
    ::google::protobuf::RepeatedPtrField< ::onnx::SequenceProto > sequence_values_;
    ::google::protobuf::RepeatedPtrField< ::onnx::MapProto > map_values_;
    ::google::protobuf::RepeatedPtrField< ::onnx::OptionalProto > optional_values_;
    ::google::protobuf::internal::ArenaStringPtr name_;
    ::int32_t elem_type_;
    PROTOBUF_TSAN_DECLARE_MEMBER
  };
  union { Impl_ _impl_; };
  friend struct ::TableStruct_onnx_2fonnx_2ddata_2eproto;
};

extern const ::google::protobuf::internal::ClassDataFull SequenceProto_class_data_;

// ===================================================================




// ===================================================================


#ifdef __GNUC__
#pragma GCC diagnostic push
#pragma GCC diagnostic ignored "-Wstrict-aliasing"
#endif  // __GNUC__
// -------------------------------------------------------------------

// SequenceProto

// optional string name = 1;
inline bool SequenceProto::has_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000020U);
  return value;
}
inline void SequenceProto::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000020U);
}
inline const ::std::string& SequenceProto::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void SequenceProto::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:onnx.SequenceProto.name)
}
inline ::std::string* PROTOBUF_NONNULL SequenceProto::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:onnx.SequenceProto.name)
  return _s;
}
inline const ::std::string& SequenceProto::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void SequenceProto::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL SequenceProto::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE SequenceProto::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.SequenceProto.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000020U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void SequenceProto::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:onnx.SequenceProto.name)
}

// optional int32 elem_type = 2;
inline bool SequenceProto::has_elem_type() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000040U);
  return value;
}
inline void SequenceProto::clear_elem_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.elem_type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000040U);
}
inline ::int32_t SequenceProto::elem_type() const {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.elem_type)
  return _internal_elem_type();
}
inline void SequenceProto::set_elem_type(::int32_t value) {
  _internal_set_elem_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  // @@protoc_insertion_point(field_set:onnx.SequenceProto.elem_type)
}
inline ::int32_t SequenceProto::_internal_elem_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.elem_type_;
}
inline void SequenceProto::_internal_set_elem_type(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.elem_type_ = value;
}

// repeated .onnx.TensorProto tensor_values = 3;
inline int SequenceProto::_internal_tensor_values_size() const {
  return _internal_tensor_values().size();
}
inline int SequenceProto::tensor_values_size() const {
  return _internal_tensor_values_size();
}
inline ::onnx::TensorProto* PROTOBUF_NONNULL SequenceProto::mutable_tensor_values(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:onnx.SequenceProto.tensor_values)
  return _internal_mutable_tensor_values()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>* PROTOBUF_NONNULL SequenceProto::mutable_tensor_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:onnx.SequenceProto.tensor_values)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_tensor_values();
}
inline const ::onnx::TensorProto& SequenceProto::tensor_values(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.tensor_values)
  return _internal_tensor_values().Get(index);
}
inline ::onnx::TensorProto* PROTOBUF_NONNULL SequenceProto::add_tensor_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::onnx::TensorProto* _add =
      _internal_mutable_tensor_values()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:onnx.SequenceProto.tensor_values)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>& SequenceProto::tensor_values() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.SequenceProto.tensor_values)
  return _internal_tensor_values();
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>&
SequenceProto::_internal_tensor_values() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.tensor_values_;
}
inline ::google::protobuf::RepeatedPtrField<::onnx::TensorProto>* PROTOBUF_NONNULL
SequenceProto::_internal_mutable_tensor_values() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.tensor_values_;
}

// repeated .onnx.SparseTensorProto sparse_tensor_values = 4;
inline int SequenceProto::_internal_sparse_tensor_values_size() const {
  return _internal_sparse_tensor_values().size();
}
inline int SequenceProto::sparse_tensor_values_size() const {
  return _internal_sparse_tensor_values_size();
}
inline ::onnx::SparseTensorProto* PROTOBUF_NONNULL SequenceProto::mutable_sparse_tensor_values(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:onnx.SequenceProto.sparse_tensor_values)
  return _internal_mutable_sparse_tensor_values()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>* PROTOBUF_NONNULL SequenceProto::mutable_sparse_tensor_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_mutable_list:onnx.SequenceProto.sparse_tensor_values)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_sparse_tensor_values();
}
inline const ::onnx::SparseTensorProto& SequenceProto::sparse_tensor_values(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.sparse_tensor_values)
  return _internal_sparse_tensor_values().Get(index);
}
inline ::onnx::SparseTensorProto* PROTOBUF_NONNULL SequenceProto::add_sparse_tensor_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::onnx::SparseTensorProto* _add =
      _internal_mutable_sparse_tensor_values()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add:onnx.SequenceProto.sparse_tensor_values)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>& SequenceProto::sparse_tensor_values() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.SequenceProto.sparse_tensor_values)
  return _internal_sparse_tensor_values();
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>&
SequenceProto::_internal_sparse_tensor_values() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.sparse_tensor_values_;
}
inline ::google::protobuf::RepeatedPtrField<::onnx::SparseTensorProto>* PROTOBUF_NONNULL
SequenceProto::_internal_mutable_sparse_tensor_values() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.sparse_tensor_values_;
}

// repeated .onnx.SequenceProto sequence_values = 5;
inline int SequenceProto::_internal_sequence_values_size() const {
  return _internal_sequence_values().size();
}
inline int SequenceProto::sequence_values_size() const {
  return _internal_sequence_values_size();
}
inline void SequenceProto::clear_sequence_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.sequence_values_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000004U);
}
inline ::onnx::SequenceProto* PROTOBUF_NONNULL SequenceProto::mutable_sequence_values(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:onnx.SequenceProto.sequence_values)
  return _internal_mutable_sequence_values()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>* PROTOBUF_NONNULL SequenceProto::mutable_sequence_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_mutable_list:onnx.SequenceProto.sequence_values)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_sequence_values();
}
inline const ::onnx::SequenceProto& SequenceProto::sequence_values(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.sequence_values)
  return _internal_sequence_values().Get(index);
}
inline ::onnx::SequenceProto* PROTOBUF_NONNULL SequenceProto::add_sequence_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::onnx::SequenceProto* _add =
      _internal_mutable_sequence_values()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000004U);
  // @@protoc_insertion_point(field_add:onnx.SequenceProto.sequence_values)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>& SequenceProto::sequence_values() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.SequenceProto.sequence_values)
  return _internal_sequence_values();
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>&
SequenceProto::_internal_sequence_values() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.sequence_values_;
}
inline ::google::protobuf::RepeatedPtrField<::onnx::SequenceProto>* PROTOBUF_NONNULL
SequenceProto::_internal_mutable_sequence_values() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.sequence_values_;
}

// repeated .onnx.MapProto map_values = 6;
inline int SequenceProto::_internal_map_values_size() const {
  return _internal_map_values().size();
}
inline int SequenceProto::map_values_size() const {
  return _internal_map_values_size();
}
inline void SequenceProto::clear_map_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.map_values_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000008U);
}
inline ::onnx::MapProto* PROTOBUF_NONNULL SequenceProto::mutable_map_values(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:onnx.SequenceProto.map_values)
  return _internal_mutable_map_values()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::onnx::MapProto>* PROTOBUF_NONNULL SequenceProto::mutable_map_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_mutable_list:onnx.SequenceProto.map_values)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_map_values();
}
inline const ::onnx::MapProto& SequenceProto::map_values(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.map_values)
  return _internal_map_values().Get(index);
}
inline ::onnx::MapProto* PROTOBUF_NONNULL SequenceProto::add_map_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::onnx::MapProto* _add =
      _internal_mutable_map_values()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000008U);
  // @@protoc_insertion_point(field_add:onnx.SequenceProto.map_values)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::MapProto>& SequenceProto::map_values() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.SequenceProto.map_values)
  return _internal_map_values();
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::MapProto>&
SequenceProto::_internal_map_values() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.map_values_;
}
inline ::google::protobuf::RepeatedPtrField<::onnx::MapProto>* PROTOBUF_NONNULL
SequenceProto::_internal_mutable_map_values() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.map_values_;
}

// repeated .onnx.OptionalProto optional_values = 7;
inline int SequenceProto::_internal_optional_values_size() const {
  return _internal_optional_values().size();
}
inline int SequenceProto::optional_values_size() const {
  return _internal_optional_values_size();
}
inline void SequenceProto::clear_optional_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.optional_values_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000010U);
}
inline ::onnx::OptionalProto* PROTOBUF_NONNULL SequenceProto::mutable_optional_values(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:onnx.SequenceProto.optional_values)
  return _internal_mutable_optional_values()->Mutable(index);
}
inline ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>* PROTOBUF_NONNULL SequenceProto::mutable_optional_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_mutable_list:onnx.SequenceProto.optional_values)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_optional_values();
}
inline const ::onnx::OptionalProto& SequenceProto::optional_values(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.SequenceProto.optional_values)
  return _internal_optional_values().Get(index);
}
inline ::onnx::OptionalProto* PROTOBUF_NONNULL SequenceProto::add_optional_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::onnx::OptionalProto* _add =
      _internal_mutable_optional_values()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_add:onnx.SequenceProto.optional_values)
  return _add;
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>& SequenceProto::optional_values() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.SequenceProto.optional_values)
  return _internal_optional_values();
}
inline const ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>&
SequenceProto::_internal_optional_values() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.optional_values_;
}
inline ::google::protobuf::RepeatedPtrField<::onnx::OptionalProto>* PROTOBUF_NONNULL
SequenceProto::_internal_mutable_optional_values() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.optional_values_;
}

// -------------------------------------------------------------------

// MapProto

// optional string name = 1;
inline bool MapProto::has_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  return value;
}
inline void MapProto::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000004U);
}
inline const ::std::string& MapProto::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.MapProto.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void MapProto::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:onnx.MapProto.name)
}
inline ::std::string* PROTOBUF_NONNULL MapProto::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:onnx.MapProto.name)
  return _s;
}
inline const ::std::string& MapProto::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void MapProto::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL MapProto::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE MapProto::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.MapProto.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000004U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void MapProto::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:onnx.MapProto.name)
}

// optional int32 key_type = 2;
inline bool MapProto::has_key_type() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  return value;
}
inline void MapProto::clear_key_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.key_type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000010U);
}
inline ::int32_t MapProto::key_type() const {
  // @@protoc_insertion_point(field_get:onnx.MapProto.key_type)
  return _internal_key_type();
}
inline void MapProto::set_key_type(::int32_t value) {
  _internal_set_key_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  // @@protoc_insertion_point(field_set:onnx.MapProto.key_type)
}
inline ::int32_t MapProto::_internal_key_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.key_type_;
}
inline void MapProto::_internal_set_key_type(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.key_type_ = value;
}

// repeated int64 keys = 3;
inline int MapProto::_internal_keys_size() const {
  return _internal_keys().size();
}
inline int MapProto::keys_size() const {
  return _internal_keys_size();
}
inline void MapProto::clear_keys() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.keys_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000001U);
}
inline ::int64_t MapProto::keys(int index) const {
  // @@protoc_insertion_point(field_get:onnx.MapProto.keys)
  return _internal_keys().Get(index);
}
inline void MapProto::set_keys(int index, ::int64_t value) {
  _internal_mutable_keys()->Set(index, value);
  // @@protoc_insertion_point(field_set:onnx.MapProto.keys)
}
inline void MapProto::add_keys(::int64_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _internal_mutable_keys()->InternalAddWithArena(
      internal_visibility(), GetArena(), value);
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_add:onnx.MapProto.keys)
}
inline const ::google::protobuf::RepeatedField<::int64_t>& MapProto::keys() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.MapProto.keys)
  return _internal_keys();
}
inline ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL MapProto::mutable_keys()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000001U);
  // @@protoc_insertion_point(field_mutable_list:onnx.MapProto.keys)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_keys();
}
inline const ::google::protobuf::RepeatedField<::int64_t>&
MapProto::_internal_keys() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.keys_;
}
inline ::google::protobuf::RepeatedField<::int64_t>* PROTOBUF_NONNULL
MapProto::_internal_mutable_keys() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.keys_;
}

// repeated bytes string_keys = 4;
inline int MapProto::_internal_string_keys_size() const {
  return _internal_string_keys().size();
}
inline int MapProto::string_keys_size() const {
  return _internal_string_keys_size();
}
inline void MapProto::clear_string_keys() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.string_keys_.Clear();
  ClearHasBitForRepeated(_impl_._has_bits_[0],
                  0x00000002U);
}
inline ::std::string* PROTOBUF_NONNULL MapProto::add_string_keys()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::std::string* _s =
      _internal_mutable_string_keys()->InternalAddWithArena(
          ::google::protobuf::MessageLite::internal_visibility(), GetArena());
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add_mutable:onnx.MapProto.string_keys)
  return _s;
}
inline const ::std::string& MapProto::string_keys(int index) const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.MapProto.string_keys)
  return _internal_string_keys().Get(index);
}
inline ::std::string* PROTOBUF_NONNULL MapProto::mutable_string_keys(int index)
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_mutable:onnx.MapProto.string_keys)
  return _internal_mutable_string_keys()->Mutable(index);
}
template <typename Arg_, typename... Args_>
inline void MapProto::set_string_keys(int index, Arg_&& value, Args_... args) {
  ::google::protobuf::internal::AssignToString(*_internal_mutable_string_keys()->Mutable(index), ::std::forward<Arg_>(value),
                        args... , ::google::protobuf::internal::BytesTag{});
  // @@protoc_insertion_point(field_set:onnx.MapProto.string_keys)
}
template <typename Arg_, typename... Args_>
inline void MapProto::add_string_keys(Arg_&& value, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  ::google::protobuf::internal::AddToRepeatedPtrField(
      ::google::protobuf::MessageLite::internal_visibility(), GetArena(),
      *_internal_mutable_string_keys(), ::std::forward<Arg_>(value),
      args... , ::google::protobuf::internal::BytesTag{});
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_add:onnx.MapProto.string_keys)
}
inline const ::google::protobuf::RepeatedPtrField<::std::string>& MapProto::string_keys()
    const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_list:onnx.MapProto.string_keys)
  return _internal_string_keys();
}
inline ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
MapProto::mutable_string_keys() ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBitForRepeated(_impl_._has_bits_[0], 0x00000002U);
  // @@protoc_insertion_point(field_mutable_list:onnx.MapProto.string_keys)
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _internal_mutable_string_keys();
}
inline const ::google::protobuf::RepeatedPtrField<::std::string>&
MapProto::_internal_string_keys() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.string_keys_;
}
inline ::google::protobuf::RepeatedPtrField<::std::string>* PROTOBUF_NONNULL
MapProto::_internal_mutable_string_keys() {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return &_impl_.string_keys_;
}

// optional .onnx.SequenceProto values = 5;
inline bool MapProto::has_values() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  PROTOBUF_ASSUME(!value || _impl_.values_ != nullptr);
  return value;
}
inline void MapProto::clear_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.values_ != nullptr) _impl_.values_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000008U);
}
inline const ::onnx::SequenceProto& MapProto::_internal_values() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::onnx::SequenceProto* p = _impl_.values_;
  return p != nullptr ? *p : reinterpret_cast<const ::onnx::SequenceProto&>(::onnx::_SequenceProto_default_instance_);
}
inline const ::onnx::SequenceProto& MapProto::values() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.MapProto.values)
  return _internal_values();
}
inline void MapProto::unsafe_arena_set_allocated_values(
    ::onnx::SequenceProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.values_);
  }
  _impl_.values_ = reinterpret_cast<::onnx::SequenceProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:onnx.MapProto.values)
}
inline ::onnx::SequenceProto* PROTOBUF_NULLABLE MapProto::release_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::onnx::SequenceProto* released = _impl_.values_;
  _impl_.values_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::onnx::SequenceProto* PROTOBUF_NULLABLE MapProto::unsafe_arena_release_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.MapProto.values)

  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::onnx::SequenceProto* temp = _impl_.values_;
  _impl_.values_ = nullptr;
  return temp;
}
inline ::onnx::SequenceProto* PROTOBUF_NONNULL MapProto::_internal_mutable_values() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.values_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::onnx::SequenceProto>(GetArena());
    _impl_.values_ = reinterpret_cast<::onnx::SequenceProto*>(p);
  }
  return _impl_.values_;
}
inline ::onnx::SequenceProto* PROTOBUF_NONNULL MapProto::mutable_values()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::onnx::SequenceProto* _msg = _internal_mutable_values();
  // @@protoc_insertion_point(field_mutable:onnx.MapProto.values)
  return _msg;
}
inline void MapProto::set_allocated_values(::onnx::SequenceProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.values_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }

  _impl_.values_ = reinterpret_cast<::onnx::SequenceProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:onnx.MapProto.values)
}

// -------------------------------------------------------------------

// OptionalProto

// optional string name = 1;
inline bool OptionalProto::has_name() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000001U);
  return value;
}
inline void OptionalProto::clear_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.ClearToEmpty();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000001U);
}
inline const ::std::string& OptionalProto::name() const
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.name)
  return _internal_name();
}
template <typename Arg_, typename... Args_>
PROTOBUF_ALWAYS_INLINE void OptionalProto::set_name(Arg_&& arg, Args_... args) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  _impl_.name_.Set(static_cast<Arg_&&>(arg), args..., GetArena());
  // @@protoc_insertion_point(field_set:onnx.OptionalProto.name)
}
inline ::std::string* PROTOBUF_NONNULL OptionalProto::mutable_name()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  ::std::string* _s = _internal_mutable_name();
  // @@protoc_insertion_point(field_mutable:onnx.OptionalProto.name)
  return _s;
}
inline const ::std::string& OptionalProto::_internal_name() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.name_.Get();
}
inline void OptionalProto::_internal_set_name(const ::std::string& value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.name_.Set(value, GetArena());
}
inline ::std::string* PROTOBUF_NONNULL OptionalProto::_internal_mutable_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  return _impl_.name_.Mutable( GetArena());
}
inline ::std::string* PROTOBUF_NULLABLE OptionalProto::release_name() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.OptionalProto.name)
  if (!CheckHasBit(_impl_._has_bits_[0], 0x00000001U)) {
    return nullptr;
  }
  ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  auto* released = _impl_.name_.Release();
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString()) {
    _impl_.name_.Set("", GetArena());
  }
  return released;
}
inline void OptionalProto::set_allocated_name(::std::string* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000001U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000001U);
  }
  _impl_.name_.SetAllocated(value, GetArena());
  if (::google::protobuf::internal::DebugHardenForceCopyDefaultString() && _impl_.name_.IsDefault()) {
    _impl_.name_.Set("", GetArena());
  }
  // @@protoc_insertion_point(field_set_allocated:onnx.OptionalProto.name)
}

// optional int32 elem_type = 2;
inline bool OptionalProto::has_elem_type() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000040U);
  return value;
}
inline void OptionalProto::clear_elem_type() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.elem_type_ = 0;
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000040U);
}
inline ::int32_t OptionalProto::elem_type() const {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.elem_type)
  return _internal_elem_type();
}
inline void OptionalProto::set_elem_type(::int32_t value) {
  _internal_set_elem_type(value);
  SetHasBit(_impl_._has_bits_[0], 0x00000040U);
  // @@protoc_insertion_point(field_set:onnx.OptionalProto.elem_type)
}
inline ::int32_t OptionalProto::_internal_elem_type() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  return _impl_.elem_type_;
}
inline void OptionalProto::_internal_set_elem_type(::int32_t value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  _impl_.elem_type_ = value;
}

// optional .onnx.TensorProto tensor_value = 3;
inline bool OptionalProto::has_tensor_value() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000002U);
  PROTOBUF_ASSUME(!value || _impl_.tensor_value_ != nullptr);
  return value;
}
inline const ::onnx::TensorProto& OptionalProto::_internal_tensor_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::onnx::TensorProto* p = _impl_.tensor_value_;
  return p != nullptr ? *p : reinterpret_cast<const ::onnx::TensorProto&>(::onnx::_TensorProto_default_instance_);
}
inline const ::onnx::TensorProto& OptionalProto::tensor_value() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.tensor_value)
  return _internal_tensor_value();
}
inline void OptionalProto::unsafe_arena_set_allocated_tensor_value(
    ::onnx::TensorProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.tensor_value_);
  }
  _impl_.tensor_value_ = reinterpret_cast<::onnx::TensorProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:onnx.OptionalProto.tensor_value)
}
inline ::onnx::TensorProto* PROTOBUF_NULLABLE OptionalProto::release_tensor_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::onnx::TensorProto* released = _impl_.tensor_value_;
  _impl_.tensor_value_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::onnx::TensorProto* PROTOBUF_NULLABLE OptionalProto::unsafe_arena_release_tensor_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.OptionalProto.tensor_value)

  ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::onnx::TensorProto* temp = _impl_.tensor_value_;
  _impl_.tensor_value_ = nullptr;
  return temp;
}
inline ::onnx::TensorProto* PROTOBUF_NONNULL OptionalProto::_internal_mutable_tensor_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.tensor_value_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::onnx::TensorProto>(GetArena());
    _impl_.tensor_value_ = reinterpret_cast<::onnx::TensorProto*>(p);
  }
  return _impl_.tensor_value_;
}
inline ::onnx::TensorProto* PROTOBUF_NONNULL OptionalProto::mutable_tensor_value()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  ::onnx::TensorProto* _msg = _internal_mutable_tensor_value();
  // @@protoc_insertion_point(field_mutable:onnx.OptionalProto.tensor_value)
  return _msg;
}
inline void OptionalProto::set_allocated_tensor_value(::onnx::TensorProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.tensor_value_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000002U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000002U);
  }

  _impl_.tensor_value_ = reinterpret_cast<::onnx::TensorProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:onnx.OptionalProto.tensor_value)
}

// optional .onnx.SparseTensorProto sparse_tensor_value = 4;
inline bool OptionalProto::has_sparse_tensor_value() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000004U);
  PROTOBUF_ASSUME(!value || _impl_.sparse_tensor_value_ != nullptr);
  return value;
}
inline const ::onnx::SparseTensorProto& OptionalProto::_internal_sparse_tensor_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::onnx::SparseTensorProto* p = _impl_.sparse_tensor_value_;
  return p != nullptr ? *p : reinterpret_cast<const ::onnx::SparseTensorProto&>(::onnx::_SparseTensorProto_default_instance_);
}
inline const ::onnx::SparseTensorProto& OptionalProto::sparse_tensor_value() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.sparse_tensor_value)
  return _internal_sparse_tensor_value();
}
inline void OptionalProto::unsafe_arena_set_allocated_sparse_tensor_value(
    ::onnx::SparseTensorProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.sparse_tensor_value_);
  }
  _impl_.sparse_tensor_value_ = reinterpret_cast<::onnx::SparseTensorProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:onnx.OptionalProto.sparse_tensor_value)
}
inline ::onnx::SparseTensorProto* PROTOBUF_NULLABLE OptionalProto::release_sparse_tensor_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::onnx::SparseTensorProto* released = _impl_.sparse_tensor_value_;
  _impl_.sparse_tensor_value_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::onnx::SparseTensorProto* PROTOBUF_NULLABLE OptionalProto::unsafe_arena_release_sparse_tensor_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.OptionalProto.sparse_tensor_value)

  ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::onnx::SparseTensorProto* temp = _impl_.sparse_tensor_value_;
  _impl_.sparse_tensor_value_ = nullptr;
  return temp;
}
inline ::onnx::SparseTensorProto* PROTOBUF_NONNULL OptionalProto::_internal_mutable_sparse_tensor_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.sparse_tensor_value_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::onnx::SparseTensorProto>(GetArena());
    _impl_.sparse_tensor_value_ = reinterpret_cast<::onnx::SparseTensorProto*>(p);
  }
  return _impl_.sparse_tensor_value_;
}
inline ::onnx::SparseTensorProto* PROTOBUF_NONNULL OptionalProto::mutable_sparse_tensor_value()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  ::onnx::SparseTensorProto* _msg = _internal_mutable_sparse_tensor_value();
  // @@protoc_insertion_point(field_mutable:onnx.OptionalProto.sparse_tensor_value)
  return _msg;
}
inline void OptionalProto::set_allocated_sparse_tensor_value(::onnx::SparseTensorProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.sparse_tensor_value_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = reinterpret_cast<::google::protobuf::Message*>(value)->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000004U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000004U);
  }

  _impl_.sparse_tensor_value_ = reinterpret_cast<::onnx::SparseTensorProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:onnx.OptionalProto.sparse_tensor_value)
}

// optional .onnx.SequenceProto sequence_value = 5;
inline bool OptionalProto::has_sequence_value() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000008U);
  PROTOBUF_ASSUME(!value || _impl_.sequence_value_ != nullptr);
  return value;
}
inline void OptionalProto::clear_sequence_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.sequence_value_ != nullptr) _impl_.sequence_value_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000008U);
}
inline const ::onnx::SequenceProto& OptionalProto::_internal_sequence_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::onnx::SequenceProto* p = _impl_.sequence_value_;
  return p != nullptr ? *p : reinterpret_cast<const ::onnx::SequenceProto&>(::onnx::_SequenceProto_default_instance_);
}
inline const ::onnx::SequenceProto& OptionalProto::sequence_value() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.sequence_value)
  return _internal_sequence_value();
}
inline void OptionalProto::unsafe_arena_set_allocated_sequence_value(
    ::onnx::SequenceProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.sequence_value_);
  }
  _impl_.sequence_value_ = reinterpret_cast<::onnx::SequenceProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:onnx.OptionalProto.sequence_value)
}
inline ::onnx::SequenceProto* PROTOBUF_NULLABLE OptionalProto::release_sequence_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::onnx::SequenceProto* released = _impl_.sequence_value_;
  _impl_.sequence_value_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::onnx::SequenceProto* PROTOBUF_NULLABLE OptionalProto::unsafe_arena_release_sequence_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.OptionalProto.sequence_value)

  ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::onnx::SequenceProto* temp = _impl_.sequence_value_;
  _impl_.sequence_value_ = nullptr;
  return temp;
}
inline ::onnx::SequenceProto* PROTOBUF_NONNULL OptionalProto::_internal_mutable_sequence_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.sequence_value_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::onnx::SequenceProto>(GetArena());
    _impl_.sequence_value_ = reinterpret_cast<::onnx::SequenceProto*>(p);
  }
  return _impl_.sequence_value_;
}
inline ::onnx::SequenceProto* PROTOBUF_NONNULL OptionalProto::mutable_sequence_value()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  ::onnx::SequenceProto* _msg = _internal_mutable_sequence_value();
  // @@protoc_insertion_point(field_mutable:onnx.OptionalProto.sequence_value)
  return _msg;
}
inline void OptionalProto::set_allocated_sequence_value(::onnx::SequenceProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.sequence_value_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000008U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000008U);
  }

  _impl_.sequence_value_ = reinterpret_cast<::onnx::SequenceProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:onnx.OptionalProto.sequence_value)
}

// optional .onnx.MapProto map_value = 6;
inline bool OptionalProto::has_map_value() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000010U);
  PROTOBUF_ASSUME(!value || _impl_.map_value_ != nullptr);
  return value;
}
inline void OptionalProto::clear_map_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.map_value_ != nullptr) _impl_.map_value_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000010U);
}
inline const ::onnx::MapProto& OptionalProto::_internal_map_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::onnx::MapProto* p = _impl_.map_value_;
  return p != nullptr ? *p : reinterpret_cast<const ::onnx::MapProto&>(::onnx::_MapProto_default_instance_);
}
inline const ::onnx::MapProto& OptionalProto::map_value() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.map_value)
  return _internal_map_value();
}
inline void OptionalProto::unsafe_arena_set_allocated_map_value(
    ::onnx::MapProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.map_value_);
  }
  _impl_.map_value_ = reinterpret_cast<::onnx::MapProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:onnx.OptionalProto.map_value)
}
inline ::onnx::MapProto* PROTOBUF_NULLABLE OptionalProto::release_map_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::onnx::MapProto* released = _impl_.map_value_;
  _impl_.map_value_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::onnx::MapProto* PROTOBUF_NULLABLE OptionalProto::unsafe_arena_release_map_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.OptionalProto.map_value)

  ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::onnx::MapProto* temp = _impl_.map_value_;
  _impl_.map_value_ = nullptr;
  return temp;
}
inline ::onnx::MapProto* PROTOBUF_NONNULL OptionalProto::_internal_mutable_map_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.map_value_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::onnx::MapProto>(GetArena());
    _impl_.map_value_ = reinterpret_cast<::onnx::MapProto*>(p);
  }
  return _impl_.map_value_;
}
inline ::onnx::MapProto* PROTOBUF_NONNULL OptionalProto::mutable_map_value()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  ::onnx::MapProto* _msg = _internal_mutable_map_value();
  // @@protoc_insertion_point(field_mutable:onnx.OptionalProto.map_value)
  return _msg;
}
inline void OptionalProto::set_allocated_map_value(::onnx::MapProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.map_value_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000010U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000010U);
  }

  _impl_.map_value_ = reinterpret_cast<::onnx::MapProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:onnx.OptionalProto.map_value)
}

// optional .onnx.OptionalProto optional_value = 7;
inline bool OptionalProto::has_optional_value() const {
  bool value = CheckHasBit(_impl_._has_bits_[0], 0x00000020U);
  PROTOBUF_ASSUME(!value || _impl_.optional_value_ != nullptr);
  return value;
}
inline void OptionalProto::clear_optional_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.optional_value_ != nullptr) _impl_.optional_value_->Clear();
  ClearHasBit(_impl_._has_bits_[0],
                  0x00000020U);
}
inline const ::onnx::OptionalProto& OptionalProto::_internal_optional_value() const {
  ::google::protobuf::internal::TSanRead(&_impl_);
  const ::onnx::OptionalProto* p = _impl_.optional_value_;
  return p != nullptr ? *p : reinterpret_cast<const ::onnx::OptionalProto&>(::onnx::_OptionalProto_default_instance_);
}
inline const ::onnx::OptionalProto& OptionalProto::optional_value() const ABSL_ATTRIBUTE_LIFETIME_BOUND {
  // @@protoc_insertion_point(field_get:onnx.OptionalProto.optional_value)
  return _internal_optional_value();
}
inline void OptionalProto::unsafe_arena_set_allocated_optional_value(
    ::onnx::OptionalProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (GetArena() == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.optional_value_);
  }
  _impl_.optional_value_ = reinterpret_cast<::onnx::OptionalProto*>(value);
  if (value != nullptr) {
    SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  }
  // @@protoc_insertion_point(field_unsafe_arena_set_allocated:onnx.OptionalProto.optional_value)
}
inline ::onnx::OptionalProto* PROTOBUF_NULLABLE OptionalProto::release_optional_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);

  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  ::onnx::OptionalProto* released = _impl_.optional_value_;
  _impl_.optional_value_ = nullptr;
  if (::google::protobuf::internal::DebugHardenForceCopyInRelease()) {
    auto* old = reinterpret_cast<::google::protobuf::MessageLite*>(released);
    released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    if (GetArena() == nullptr) {
      delete old;
    }
  } else {
    if (GetArena() != nullptr) {
      released = ::google::protobuf::internal::DuplicateIfNonNull(released);
    }
  }
  return released;
}
inline ::onnx::OptionalProto* PROTOBUF_NULLABLE OptionalProto::unsafe_arena_release_optional_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  // @@protoc_insertion_point(field_release:onnx.OptionalProto.optional_value)

  ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  ::onnx::OptionalProto* temp = _impl_.optional_value_;
  _impl_.optional_value_ = nullptr;
  return temp;
}
inline ::onnx::OptionalProto* PROTOBUF_NONNULL OptionalProto::_internal_mutable_optional_value() {
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (_impl_.optional_value_ == nullptr) {
    auto* p = ::google::protobuf::Message::DefaultConstruct<::onnx::OptionalProto>(GetArena());
    _impl_.optional_value_ = reinterpret_cast<::onnx::OptionalProto*>(p);
  }
  return _impl_.optional_value_;
}
inline ::onnx::OptionalProto* PROTOBUF_NONNULL OptionalProto::mutable_optional_value()
    ABSL_ATTRIBUTE_LIFETIME_BOUND {
  SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  ::onnx::OptionalProto* _msg = _internal_mutable_optional_value();
  // @@protoc_insertion_point(field_mutable:onnx.OptionalProto.optional_value)
  return _msg;
}
inline void OptionalProto::set_allocated_optional_value(::onnx::OptionalProto* PROTOBUF_NULLABLE value) {
  ::google::protobuf::Arena* message_arena = GetArena();
  ::google::protobuf::internal::TSanWrite(&_impl_);
  if (message_arena == nullptr) {
    delete reinterpret_cast<::google::protobuf::MessageLite*>(_impl_.optional_value_);
  }

  if (value != nullptr) {
    ::google::protobuf::Arena* submessage_arena = value->GetArena();
    if (message_arena != submessage_arena) {
      value = ::google::protobuf::internal::GetOwnedMessage(message_arena, value, submessage_arena);
    }
    SetHasBit(_impl_._has_bits_[0], 0x00000020U);
  } else {
    ClearHasBit(_impl_._has_bits_[0], 0x00000020U);
  }

  _impl_.optional_value_ = reinterpret_cast<::onnx::OptionalProto*>(value);
  // @@protoc_insertion_point(field_set_allocated:onnx.OptionalProto.optional_value)
}

#ifdef __GNUC__
#pragma GCC diagnostic pop
#endif  // __GNUC__

// @@protoc_insertion_point(namespace_scope)
}  // namespace onnx


namespace google {
namespace protobuf {

template <>
struct is_proto_enum<::onnx::SequenceProto_DataType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::onnx::SequenceProto_DataType>() {
  return ::onnx::SequenceProto_DataType_descriptor();
}
template <>
struct is_proto_enum<::onnx::OptionalProto_DataType> : std::true_type {};
template <>
inline const EnumDescriptor* PROTOBUF_NONNULL GetEnumDescriptor<::onnx::OptionalProto_DataType>() {
  return ::onnx::OptionalProto_DataType_descriptor();
}

}  // namespace protobuf
}  // namespace google

// @@protoc_insertion_point(global_scope)

#include "google/protobuf/port_undef.inc"
// clang-format on

#endif  // onnx_2fonnx_2ddata_2eproto_2epb_2eh
